:tocdepth: 2

.. |grappelli| replace:: Grappelli
.. |filebrowser| replace:: FileBrowser

.. _faq:

FAQ
===

Some questions, some answers.

Why should I use |grappelli|?
-----------------------------

If you are pleased with how the original admin interface looks, you probably shouldn't. Grappelli is mainly about a consistent, grid-based style.

I need help!
------------

see :ref:`Troubleshooting <troubleshooting>`.

Which Browser do I need with Grappelli?
---------------------------------------

We are testing with Firefox, Chrome and Safari. IE9 and Opera should work fine as well.

Can I use another editor than TinyMCE?
--------------------------------------

Of course (better use markdown anyway).

Why don't you use Twitter Bootstrap?
------------------------------------

For now, custom Compass-based stylesheets gives us much more options. But we do understand the need to easily customize the admin interface and we're discussing this issue on a regular basis.

Do you guys cooperate with the Django–Devs?
-------------------------------------------

Occasionally, we have been discussing features and implementations in the past.

How can I contribute?
---------------------

Help is very much appreciated.

* Fork `django-grappelli <https://github.com/sehmaschine/django-grappelli>`_ and submit feedback/patches.
* Work on `Django Tickets related to contrib.admin <https://code.djangoproject.com/query?status=assigned&status=new&status=reopened&component=contrib.admin&group=milestone&col=id&col=summary&col=status&col=owner&col=type&col=version&order=priority>`_.
* Take a look at :ref:`Django Issues <djangoissues>`.

What is your goal with |grappelli|?
-----------------------------------

Our goal is that |grappelli| will be redundant eventually (though we doubt that will happen).

Who develops |grappelli|?
-------------------------

|grappelli| is developed and maintained by Patrick Kranzlmüller & Axel Swoboda of `vonautomatisch <http://www.vonautomatisch.at>`_.
